@@ -35,7 +35,7 @@
 #include "x11utils.h"
 #endif
 
-Q_LOGGING_CATEGORY(taskManagerLog, "dde.shell.dock.taskmanager", QtDebugMsg)
+Q_LOGGING_CATEGORY(taskManagerLog, "org.deepin.dde.shell.dock.taskmanager", QtDebugMsg)
 
 #define Settings TaskManagerSettings::instance()
 
@@ -75,6 +75,7 @@ public:
         , m_role(role)
     {
         setSourceModel(sourceModel);
+        setDynamicSortFilter(false);
     }
 
 protected:
@@ -216,27 +217,27 @@ HoverPreviewProxyModel *TaskManager::hoverPreviewModel() const
 
 void TaskManager::requestActivate(const QModelIndex &index) const
 {
-    m_itemModel->requestActivate(index);
+    dataModel()->requestActivate(index);
 }
 
 void TaskManager::requestOpenUrls(const QModelIndex &index, const QList<QUrl> &urls) const
 {
-    m_itemModel->requestOpenUrls(index, urls);
+    dataModel()->requestOpenUrls(index, urls);
 }
 
 void TaskManager::requestNewInstance(const QModelIndex &index, const QString &action) const
 {
-    m_itemModel->requestNewInstance(index, action);
+    dataModel()->requestNewInstance(index, action);
 }
 
 void TaskManager::requestClose(const QModelIndex &index, bool force) const
 {
-    m_itemModel->requestClose(index, force);
+    dataModel()->requestClose(index, force);
 }
 
 void TaskManager::requestUpdateWindowIconGeometry(const QModelIndex &index, const QRect &geometry, QObject *delegate) const
 {
-    m_itemModel->requestUpdateWindowIconGeometry(index, geometry, delegate);
+    dataModel()->requestUpdateWindowIconGeometry(index, geometry, delegate);
 }
 
 void TaskManager::requestPreview(const QModelIndex &index, QObject *relativePositionItem, int32_t previewXoffset, int32_t previewYoffset, uint32_t direction)
@@ -247,7 +248,13 @@ void TaskManager::requestPreview(const QModelIndex &index, QObject *relativePosi
     }
 
     // Set the preview filter condition based on the incoming model index
-    m_hoverPreviewModel->setFilterModelIndex(index);
+    if (windowSplit()) {
+        QString winId = index.data(TaskManager::WinIdRole).toString();
+        m_hoverPreviewModel->setFilter(winId, HoverPreviewProxyModel::FilterByWinId);
+    } else {
+        QString appId = index.data(TaskManager::DesktopIdRole).toString();
+        m_hoverPreviewModel->setFilter(appId, HoverPreviewProxyModel::FilterByAppId);
+    }
 
     // Check if there are any windows after filtering
     if (m_hoverPreviewModel->rowCount() == 0) {
@@ -261,7 +268,7 @@ void TaskManager::requestPreview(const QModelIndex &index, QObject *relativePosi
 
 void TaskManager::requestWindowsView(const QModelIndexList &indexes) const
 {
-    m_itemModel->requestWindowsView(indexes);
+    dataModel()->requestWindowsView(indexes);
 }
 
 void TaskManager::handleWindowAdded(QPointer<AbstractWindow> window)
@@ -316,7 +323,7 @@ void TaskManager::dropFilesOnItem(const QString& itemId, const QStringList& urls
         urlList.append(QUrl::fromLocalFile(url));
     }
 
-    m_itemModel->requestOpenUrls(indexes.first(), urlList);
+    dataModel()->requestOpenUrls(indexes.first(), urlList);
 }
 
 void TaskManager::hideItemPreview()
@@ -381,11 +388,7 @@ bool TaskManager::IsDocked(QString appID)
         return false;
     }
 
-    QPointer<AppItem> appitem = desktopfileParser->getAppItem();
-    if (appitem.isNull()) {
-        return false;
-    }
-    return appitem->isDocked();
+    return desktopfileParser->isDocked();
 }
 
 bool TaskManager::RequestUndock(QString appID)
